.. _index:

=======
Hypatia
=======

:mod:`hypatia` is a Python indexing and searching framework.  It works on
Python 2.7+ and Python 3.3+.

Narrative documentation
-----------------------

Narrative documentation explaining how to use :mod:`hypatia`.

.. warning::

   This is under construction during the alpha phase of Hypatia.

.. toctree::
   :maxdepth: 2

   genealogy
   install
   glossary
   changes

API documentation
-----------------

API documentation for :mod:`hypatia`.

.. toctree::
   :maxdepth: 2

   api

Source Code and Issue Tracking
------------------------------

Source code is available from https://github.com/Pylons/hypatia

File bugs via https://github.com/Pylons/hypatia/issues


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`

